@@ -5,7 +5,7 @@ from collections import OrderedDict
 
 from andes.core.model import Model, ModelData
 from andes.core.param import NumParam, IdxParam
-from andes.core.block import Lag, DeadBand1, LimiterGain
+from andes.core.block import Lag, DeadBand1, GainLimiter
 from andes.core.var import ExtAlgeb, Algeb
 
 from andes.core.service import ConstService, ExtService, VarService
@@ -64,15 +64,18 @@ class PVD1Data(ModelData):
         self.qmx = NumParam(default=0.33, tex_name='q_{mx}',
                             info='Max. reactive power command',
                             power=True,
+                            unit='pu',
                             )
 
         self.qmn = NumParam(default=-0.33, tex_name='q_{mn}',
                             info='Min. reactive power command',
                             power=True,
+                            unit='pu',
                             )
         self.pmx = NumParam(default=999.0, info='maximum power limit',
                             tex_name='p_{mx}',
                             power=True,
+                            unit='pu',
                             )
 
         self.v0 = NumParam(default=0.8, tex_name='v_0',
@@ -450,13 +453,15 @@ class PVD1Model(Model):
                            )
 
         # --- `Ipcmd` and `Iqcmd` ---
-        self.Ipcmd = LimiterGain(u=self.Ipul, K='Fvl * Fvh * Ffl * Ffh',
+        self.Ipcmd = GainLimiter(u=self.Ipul,
+                                 K=1, R='Fvl * Fvh * Ffl * Ffh',
                                  lower=0, upper=self.Ipmax,
                                  info='Ip with limiter and coeff.',
                                  tex_name='I^{pcmd}',
                                  )
 
-        self.Iqcmd = LimiterGain(u=self.Iqul, K='Fvl * Fvh * Ffl * Ffh',
+        self.Iqcmd = GainLimiter(u=self.Iqul,
+                                 K=1, R='Fvl * Fvh * Ffl * Ffh',
                                  lower=self.Iqmax, sign_lower=-1,
                                  upper=self.Iqmax,
                                  info='Iq with limiter and coeff.',
@@ -471,6 +476,15 @@ class PVD1Model(Model):
                          info='Output Iq filter',
                          )
 
+        self.Pe = Algeb(tex_name='P_e',
+                        info='active power output',
+                        e_str='v * Ipout_y - Pe',
+                        v_str='pref0')
+        self.Qe = Algeb(tex_name='Q_e',
+                        info='reactive power output',
+                        e_str='v * Iqout_y - Qe',
+                        v_str='qref0')
+
     def v_numeric(self, **kwargs):
         """
         Disable the corresponding `StaticGen`s.
@@ -501,6 +515,9 @@ class PVD1(PVD1Data, PVD1Model):
     write to `pref0.v` and `qref0.v` in place.
     AGC signals should write to `pext0.v` in place.
 
+    Maximum power limit `pmx` can be enabled by editing the configuration
+    file by setting `plim=1`. It cannot be modified in runtime.
+
     Reference:
     [1] ESIG, WECC Distributed and Small PV Plants Generic Model (PVD1), [Online],
     Available:
