@@ -5,6 +5,7 @@ The Andes plotting tool.
 import os
 import re
 import logging
+import math
 
 import numpy as np
 
@@ -14,6 +15,7 @@ from andes.shared import set_latex
 from andes.core.var import BaseVar
 
 logger = logging.getLogger(__name__)
+DPI = 100
 
 
 class TDSData:
@@ -33,10 +35,10 @@ class TDSData:
         self._lst_file = None
 
         # data members for raw data
-        self._idx = []  # indices of variables
+        self._idx = []    # indices of variables
         self._uname = []  # unformatted variable names
         self._fname = []  # formatted variable names
-        self._data = []  # data loaded from file
+        self._data = []   # data loaded from file
 
         # auxillary data members for fast query
         self.t = []
@@ -217,7 +219,7 @@ class TDSData:
 
         """
 
-        if isinstance(idx, (int, np.int64)):
+        if isinstance(idx, (int, np.integer)):
             idx = [idx]
         header = self._uname if not formatted else self._fname
         return [header[x] for x in idx]
@@ -266,11 +268,13 @@ class TDSData:
              left=None, right=None, ymin=None, ymax=None,
              xlabel=None, ylabel=None, xheader=None, yheader=None,
              legend=None, grid=False, greyscale=False, latex=True,
-             dpi=150, line_width=1.0, font_size=12, savefig=None, save_format=None, show=True,
+             dpi=DPI, line_width=1.0, font_size=12, savefig=None, save_format=None, show=True,
              title=None, linestyles=None, use_bqplot=False,
              hline1=None, hline2=None, vline1=None, vline2=None,
              fig=None, ax=None, backend=None,
-             set_xlim=True, set_ylim=True, autoscale=False, legend_bbox=None, legend_loc=None,
+             set_xlim=True, set_ylim=True, autoscale=False,
+             legend_bbox=None, legend_loc=None, legend_ncol=1,
+             figsize=None,
              **kwargs):
         """
         Entry function for plotting.
@@ -318,14 +322,19 @@ class TDSData:
             A list containing the variable names for the x-axis variable
         legend : bool
             True to show legend and False otherwise
+        legend_ncol : int
+            Number of columns in legend
+        legend_bbox : tuple of two floats
+            legend box to anchor
         grid : bool
             True to show grid and False otherwise
         latex : bool
             True to enable latex and False to disable
         greyscale : bool
             True to use greyscale, False otherwise
-        savefig : bool
-            True to save to png figure file
+        savefig : bool or str
+            True to save to png figure file.
+            str is treated as the output file name.
         save_format : str
             File extension string (pdf, png or jpg) for the savefig format
         dpi : int
@@ -335,6 +344,8 @@ class TDSData:
             Plot line width
         font_size : float
             Text font size (labels and legends)
+        figsize : tuple
+            Figure size passed when creating new figure
         show : bool
             True to show the image
         backend : str or None
@@ -402,7 +413,8 @@ class TDSData:
                          hline1=hline1, hline2=hline2, vline1=vline1, vline2=vline2,
                          fig=fig, ax=ax, linestyles=linestyles,
                          set_xlim=set_xlim, set_ylim=set_ylim, autoscale=autoscale,
-                         legend_bbox=legend_bbox, legend_loc=legend_loc,
+                         legend_bbox=legend_bbox, legend_loc=legend_loc, legend_ncol=legend_ncol,
+                         figsize=figsize,
                          **kwargs)
 
     def get_call(self, backend=None):
@@ -427,7 +439,7 @@ class TDSData:
 
     def bqplot_data(self, xdata, ydata, *, xheader=None, yheader=None, xlabel=None, ylabel=None,
                     left=None, right=None, ymin=None, ymax=None, legend=True, grid=False, fig=None,
-                    latex=True, dpi=150, line_width=1.0, greyscale=False, savefig=None, save_format=None,
+                    dpi=DPI, line_width=1.0, greyscale=False, savefig=None, save_format=None,
                     title=None,
                     **kwargs):
         """
@@ -458,10 +470,11 @@ class TDSData:
 
     def plot_data(self, xdata, ydata, *, xheader=None, yheader=None, xlabel=None, ylabel=None, linestyles=None,
                   left=None, right=None, ymin=None, ymax=None, legend=None, grid=False, fig=None, ax=None,
-                  latex=True, dpi=150, line_width=1.0, font_size=12, greyscale=False, savefig=None,
+                  latex=True, dpi=DPI, line_width=1.0, font_size=12, greyscale=False, savefig=None,
                   save_format=None, show=True, title=None, hline1=None, hline2=None, vline1=None,
-                  vline2=None, set_xlim=True, set_ylim=True, autoscale=False,
-                  legend_bbox=None, legend_loc=None,
+                  vline2=None, set_xlim=True, set_ylim=True, autoscale=False, figsize=None,
+                  legend_bbox=None, legend_loc=None, legend_ncol=1,
+                  mask=True,
                   **kwargs):
         """
         Plot lines for the supplied data and options.
@@ -478,6 +491,10 @@ class TDSData:
         ydata : array
             An array containing the values of each variables for the y-axis variable. The row
             of `ydata` must match the row of `xdata`. Each column correspondings to a variable.
+        mask : bool
+            If enabled (1), when specifying axis limits, only data in the limits will be
+            used for plotting to optimize for autoscaling.
+            It is done through an index mask.
 
         Returns
         -------
@@ -523,12 +540,17 @@ class TDSData:
         linestyles = linestyles * int(n_lines / len(linestyles) + 1)
 
         if fig is None or ax is None:
-            fig = plt.figure(dpi=dpi)
+            fig = plt.figure(dpi=dpi, figsize=figsize)
             ax = plt.gca()
 
         if greyscale:
             plt.gray()
 
+        if mask is True:
+            mask = (xdata >= (left - 0.1)) & (xdata <= (right + 0.1))
+            xdata = xdata[mask]
+            ydata = ydata[mask.reshape(-1, )]
+
         for i in range(n_lines):
             ax.plot(xdata,
                     ydata[:, i],
@@ -565,7 +587,9 @@ class TDSData:
                 legend = True
 
         if legend:
-            ax.legend(bbox_to_anchor=legend_bbox, loc=legend_loc)
+            ax.legend(bbox_to_anchor=legend_bbox,
+                      loc=legend_loc,
+                      ncol=legend_ncol)
 
         if title:
             ax.set_title(title)
@@ -581,7 +605,7 @@ class TDSData:
 
         plt.draw()
 
-        if savefig:
+        if savefig is not None:
             if save_format is None:
                 save_format = 'png'
 
@@ -590,12 +614,17 @@ class TDSData:
             else:
                 dpi = max(dpi, 200)
 
-            count = 1
-            while True:
-                outfile = f'{self.file_name}_{count}.{save_format}'
-                if not os.path.isfile(outfile):
-                    break
-                count += 1
+            # use supplied file name
+            if isinstance(savefig, str):
+                outfile = savefig + '.' + save_format
+            # or generate a new name
+            else:
+                count = 1
+                while True:
+                    outfile = f'{self.file_name}_{count}.{save_format}'
+                    if not os.path.isfile(outfile):
+                        break
+                    count += 1
 
             fig.savefig(outfile, dpi=dpi)
             logger.info('Figure saved to "%s".', outfile)
@@ -605,7 +634,7 @@ class TDSData:
 
         return fig, ax
 
-    def plotn(self, nrows: int, ncols: int, yidxes, xidxes=None, *, dpi=150, titles=None,
+    def plotn(self, nrows: int, ncols: int, yidxes, xidxes=None, *, dpi=DPI, titles=None,
               a=None, figsize=None, xlabel=None, ylabel=None, sharex=None, sharey=None, show=True,
               xlabel_offs=(0.5, 0.01), ylabel_offs=(0.05, 0.5), hspace=0.2, wspace=0.2,
               **kwargs):
@@ -636,9 +665,6 @@ class TDSData:
         aidx = None
         title = ''
 
-        # assume the first xlabel
-        xlabel = self.get_header(xidx)[0] if xlabel is None else xlabel
-
         sharex = True if (sharex is None and ncols == 1) else False
         sharey = True if (sharey is None and nrows == 1) else False
 
@@ -677,6 +703,105 @@ class TDSData:
 
         return fig, axes
 
+    def panoview(self, mdl, *, ncols=3, vars=None, idx=None, a=None, figsize=None, **kwargs):
+        """
+        Panoramic view of variables of a given model instance.
+
+        Select variables through ``vars``. Select devices through ``idx`` or ``a``,
+        which has a higher priority.
+
+        This function also takes other arguments recognizable by ``self.plot``.
+
+        Parameters
+        ----------
+        mdl : ModelBase
+            Model instance
+        ncol : int
+            Number of columns
+        var : list of str
+            A list of variable names to display
+        idx : list
+            A list of device idx-es for showing
+        a : list of int
+            A list of device 0-based positions for showing
+        figsize : tuple
+            Figure size for plotting
+
+        Examples
+        --------
+        To plot ``omega`` and ``delta`` of GENROUs ``GENROU_1`` and ``GENROU_2``:
+
+        .. code-block :: python
+
+            system.TDS.plt.plot(system.GENROU,
+                                vars=['omega', 'delta'],
+                                idx=['GENROU_1', 'GENROU_2'])
+
+        """
+        # `a` takes precedece over `idx`
+        if a is None:
+            a = mdl.idx2uid(idx)
+
+        # compute the number of rows and cols
+        states = list()
+        algebs = list()
+
+        if vars is None:
+            states = mdl.states.values()
+            algebs = mdl.algebs.values()
+        else:
+            for item in vars:
+                if item in mdl.states:
+                    states.append(mdl.states[item])
+                elif item in mdl.algebs:
+                    algebs.append(mdl.algebs[item])
+                else:
+                    logger.warning("Variable <%s> does not exist in model <%s>",
+                                   item, mdl.class_name)
+        nstates = len(states)
+        nalgebs = len(algebs)
+
+        nrows_states = math.ceil(nstates / ncols)
+        nrows_algebs = math.ceil(nalgebs / ncols)
+
+        # build canvas
+        if figsize is None:
+            figsize = (3 * ncols, 2 * (nrows_states + nrows_algebs))
+
+        fig, axes = plt.subplots(nrows_states + nrows_algebs, ncols,
+                                 figsize=figsize, dpi=DPI, squeeze=False,
+                                 )
+        fig.tight_layout()
+
+        # turn off unused axes
+        if nstates % ncols != 0:
+            for i in range(nstates % ncols, ncols):
+                axes[nrows_states-1, i].axis('off')
+
+        if nalgebs % ncols != 0:
+            for i in range(nalgebs % ncols, ncols):
+                axes[-1, i].axis('off')
+
+        # plot states
+        for ii, item in enumerate(states):
+            row_no = math.floor(ii / ncols)
+            col_no = ii % ncols
+            self.plot(item, a=a,
+                      title=f'${item.tex_name}$',
+                      xlabel='',
+                      fig=fig, ax=axes[row_no, col_no], show=False, **kwargs)
+
+        # plot algebs
+        for ii, item in enumerate(algebs):
+            row_no = math.floor(ii / ncols) + nrows_states
+            col_no = ii % ncols
+            self.plot(item, a=a,
+                      title=f'${item.tex_name}$',
+                      xlabel='',
+                      fig=fig, ax=axes[row_no, col_no], show=False, **kwargs)
+
+        return fig, axes
+
 
 def parse_y(y, upper, lower=0):
     """
@@ -833,26 +958,6 @@ def tdsplot(filename, y, x=(0,),
         raise NotImplementedError("Plotting multiple data files are not supported yet")
 
 
-def check_init(yval, yl):
-    """"
-    Check initialization by comparing t=0 and t=end values for a flat run.
-
-    Warnings
-    --------
-    This function is deprecated as the initialization check feature is built into TDS.
-    See ``TDS.test_initialization()``.
-    """
-    suspect = []
-    for var, label in zip(yval, yl):
-        if abs(var[0] - var[-1]) >= 1e-6:
-            suspect.append(label)
-    if suspect:
-        logger.error('Initialization failed:')
-        logger.error(', '.join(suspect))
-    else:
-        logger.error('Initialization is correct.')
-
-
 def isfloat(value):
     try:
         float(value)
