@@ -22,6 +22,7 @@ class PFlow(BaseRoutine):
         self.config.add(OrderedDict((('tol', 1e-6),
                                      ('max_iter', 25),
                                      ('method', 'NR'),
+                                     ('check_conn', 1),
                                      ('n_factorize', 4),
                                      ('report', 1),
                                      ('degree', 0),
@@ -31,6 +32,7 @@ class PFlow(BaseRoutine):
                               tol="convergence tolerance",
                               max_iter="max. number of iterations",
                               method="calculation method",
+                              check_conn='check connectivity before power flow',
                               n_factorize="first N iterations to factorize Jacobian in dishonest method",
                               report="write output report",
                               degree='use degree in report',
@@ -39,6 +41,7 @@ class PFlow(BaseRoutine):
         self.config.add_extra("_alt",
                               tol="float",
                               method=("NR", "dishonest"),
+                              check_conn=(0, 1),
                               max_iter=">=10",
                               n_factorize=">0",
                               report=(0, 1),
@@ -50,33 +53,36 @@ class PFlow(BaseRoutine):
         self.inc = None
         self.A = None
         self.niter = None
-        self.mis = []
+        self.mis = [1]
         self.models = OrderedDict()
 
         self.x_sol = None
         self.y_sol = None
 
     def init(self):
-        self.models = self.system.find_models('pflow')
+        system = self.system
+
+        self.models = system.find_models('pflow')
         self.converged = False
         self.inc = None
         self.A = None
         self.niter = None
-        self.mis = []
+        self.mis = [1]
 
         self.x_sol = None
         self.y_sol = None
 
+        self.system.set_var_arrays(self.models, inplace=True, alloc=False)
         self.system.init(self.models, routine='pflow')
         logger.info('Power flow initialized.')
 
         # force precompile if numba is on - improves timing accuracy
-        if self.system.config.numba:
-            self.system.f_update(self.models)
-            self.system.g_update(self.models)
-            self.system.j_update(models=self.models)
+        if system.config.numba:
+            system.f_update(self.models)
+            system.g_update(self.models)
+            system.j_update(models=self.models)
 
-        return self.system.dae.xy
+        return system.dae.xy
 
     def nr_step(self):
         """
@@ -90,7 +96,7 @@ class PFlow(BaseRoutine):
         system = self.system
         # evaluate discrete, differential, algebraic, and Jacobians
         system.dae.clear_fg()
-        system.l_update_var(self.models)
+        system.l_update_var(self.models, niter=self.niter, err=self.mis[-1])
         system.s_update_var(self.models)
         system.f_update(self.models)
         system.g_update(self.models)
@@ -118,8 +124,22 @@ class PFlow(BaseRoutine):
         system.dae.x += np.ravel(np.array(self.inc[:system.dae.n]))
         system.dae.y += np.ravel(np.array(self.inc[system.dae.n:]))
 
-        mis = np.max(np.abs(system.dae.fg))
-        self.mis.append(mis)
+        # find out variables associated with maximum mismatches
+        fmax = 0
+        if system.dae.n > 0:
+            fmax_idx = np.argmax(np.abs(system.dae.f))
+            fmax = system.dae.f[fmax_idx]
+            logger.debug("Max. diff mismatch %.10g on %s", fmax, system.dae.x_name[fmax_idx])
+
+        gmax_idx = np.argmax(np.abs(system.dae.g))
+        gmax = system.dae.g[gmax_idx]
+        logger.debug("Max. algeb mismatch %.10g on %s", gmax, system.dae.y_name[gmax_idx])
+
+        mis = max(abs(fmax), abs(gmax))
+        if self.niter == 0:
+            self.mis[0] = mis
+        else:
+            self.mis.append(mis)
 
         system.vars_to_models()
 
@@ -129,9 +149,9 @@ class PFlow(BaseRoutine):
         """
         Output a summary for the PFlow routine.
         """
-        ipadd_status = 'CVXOPT normal (ipadd not available)'
+        ipadd_status = 'Standard (ipadd not available)'
 
-        # extract package name, `cvxopt` or `kvxopt`
+        # extract package name, `kvxopt` or `kvxopt`
         sp_module = sparse.__module__
         if '.' in sp_module:
             sp_module = sp_module.split('.')[0]
@@ -140,7 +160,7 @@ class PFlow(BaseRoutine):
             if self.system.config.ipadd:
                 ipadd_status = f'Fast in-place ({sp_module})'
             else:
-                ipadd_status = 'CVXOPT normal (ipadd disabled in config)'
+                ipadd_status = 'Standard (ipadd disabled in config)'
 
         out = list()
         out.append('')
@@ -161,8 +181,12 @@ class PFlow(BaseRoutine):
             convergence status
         """
         system = self.system
+        if self.config.check_conn == 1:
+            self.system.connectivity()
+
         self.summary()
         self.init()
+
         if system.dae.m == 0:
             logger.error("Loaded case contains no power flow element.")
             system.exit_code = 1
@@ -240,7 +264,7 @@ class PFlow(BaseRoutine):
         system.vars_to_models()
 
         system.dae.clear_fg()
-        system.l_update_var(self.models)
+        system.l_update_var(self.models, niter=self.niter, err=self.mis[-1])
         system.f_update(self.models)
         system.g_update(self.models)
         system.l_update_eq(self.models)
