@@ -1,5 +1,6 @@
 import logging
 import os
+import io
 logger = logging.getLogger(__name__)
 
 
@@ -65,12 +66,11 @@ class FileMan:
         self.input_path = input_path if input_path is not None else ''
         self.output_path = output_path if output_path is not None else ''
 
-        if os.path.isfile(self.get_fullpath(case)):
-            self.case = self.get_fullpath(case)
+        self.case = case
+        if os.path.isfile(case):
+            _, self.fullname = os.path.split(self.case)
         else:
-            self.case = case
-
-        _, self.fullname = os.path.split(self.case)
+            self.fullname = ''
 
         # `self.name` is the name part without extension
         self.name, self.ext = os.path.splitext(self.fullname)
@@ -80,29 +80,30 @@ class FileMan:
         if dump is None:
             dump = self.name
 
+        # set the output file names anyway
+        if not output:
+            output = add_suffix(self.name, 'out')
+        prof = add_suffix(self.name, 'prof')
+        eig = add_suffix(self.name, 'eig')
+        mat = add_suffix(self.name, 'As')
+
+        self.lst = os.path.join(self.output_path, output + '.lst')
+        self.npy = os.path.join(self.output_path, output + '.npy')
+        self.npz = os.path.join(self.output_path, output + '.npz')
+        self.csv = os.path.join(self.output_path, output + '.csv')
+        self.txt = os.path.join(self.output_path, output + '.txt')
+
+        self.eig = os.path.join(self.output_path, eig + '.txt')
+        self.prof = os.path.join(self.output_path, prof + '.txt')
+        self.mat = os.path.join(self.output_path, mat + '.mat')
+        self.prof_raw = os.path.join(self.output_path, prof + '.prof')
+        self.dump = os.path.join(self.output_path, dump + '.xlsx')
+
+        # use `self.no_output` to control calls to saving functions
         if no_output:
             self.no_output = True
-            for item in self._out_fields:
-                self.__dict__[item] = None
         else:
             self.no_output = False
-            if not output:
-                output = add_suffix(self.name, 'out')
-            prof = add_suffix(self.name, 'prof')
-            eig = add_suffix(self.name, 'eig')
-            mat = add_suffix(self.name, 'As')
-
-            self.lst = os.path.join(self.output_path, output + '.lst')
-            self.npy = os.path.join(self.output_path, output + '.npy')
-            self.npz = os.path.join(self.output_path, output + '.npz')
-            self.csv = os.path.join(self.output_path, output + '.csv')
-            self.txt = os.path.join(self.output_path, output + '.txt')
-
-            self.eig = os.path.join(self.output_path, eig + '.txt')
-            self.prof = os.path.join(self.output_path, prof + '.txt')
-            self.mat = os.path.join(self.output_path, mat + '.mat')
-            self.prof_raw = os.path.join(self.output_path, prof + '.prof')
-            self.dump = os.path.join(self.output_path, dump + '.xlsx')
 
     def get_fullpath(self, fullname=None):
         """
@@ -118,13 +119,15 @@ class FileMan:
         # if is an empty path
         if not fullname:
             return fullname
+        if isinstance(fullname, io.IOBase):
+            return ''
 
         isabs = os.path.isabs(fullname)
 
         path, name = os.path.split(fullname)
 
         if not name:  # path to a folder
-            return None
+            return ''
         else:  # path to a file
             if isabs:
                 return fullname
